@@ -145,7 +145,7 @@ pub trait Environment {
             lamports,
             space as u64,
             &owner,
-        ));
+        )).assert_success();
     }
 
     /// Executes a transaction constructing an empty rent-excempt account with the specified amount of space, owned by the provided program.
@@ -157,7 +157,7 @@ pub trait Environment {
             self.get_rent_excemption(space),
             space as u64,
             &owner,
-        ));
+        )).assert_success();
     }
 
     /// Executes a transaction constructing a token mint. The account needs to be empty and belong to system for this to work.
@@ -187,7 +187,7 @@ pub trait Environment {
                 .unwrap(),
             ],
             &[mint],
-        );
+        ).assert_success();
     }
 
     /// Executes a transaction that mints tokens from a mint to an account belonging to that mint.
@@ -203,7 +203,7 @@ pub trait Environment {
             )
             .unwrap()],
             &[authority],
-        );
+        ).assert_success();
     }
 
     /// Executes a transaction constructing a token account of the specified mint. The account needs to be empty and belong to system for this to work.
@@ -227,7 +227,7 @@ pub trait Environment {
                 .unwrap(),
             ],
             &[account],
-        );
+        ).assert_success();
     }
 
     /// Executes a transaction constructing the associated token account of the specified mint belonging to the owner. This will fail if the account already exists.
@@ -264,7 +264,7 @@ pub trait Environment {
             self.get_rent_excemption(data.len()),
             data.len() as u64,
             &bpf_loader::id(),
-        ));
+        )).assert_success();
 
         let mut offset = 0usize;
         for chunk in data.chunks(900) {
@@ -277,7 +277,7 @@ pub trait Environment {
                     chunk.to_vec(),
                 )],
                 &[account],
-            );
+            ).assert_success();
             offset += chunk.len();
         }
     }
@@ -299,7 +299,7 @@ pub trait Environment {
                     &bpf_loader::id(),
                 )],
                 &[&keypair],
-            );
+            ).assert_success();
         }
 
         keypair.pubkey()
@@ -818,6 +818,9 @@ pub trait PrintableTransaction {
     fn print(&self) {
         self.print_named("");
     }
+
+    /// Panic and print the transaction if it did not execute successfully
+    fn assert_success(&self);
 }
 
 impl PrintableTransaction for ConfirmedTransaction {
@@ -827,6 +830,16 @@ impl PrintableTransaction for ConfirmedTransaction {
         println!("EXECUTE {} (slot {})", name, encoded.slot);
         println_transaction(&tx, &encoded.transaction.meta, "  ", None, None);
     }
+
+    fn assert_success(&self) {
+        match &self.transaction.meta {
+            Some(meta) if meta.status.is_err() => {
+                self.print();
+                panic!("tx failed!")
+            },
+            _ => (),
+        }
+    }
 }
 
 impl PrintableTransaction for EncodedConfirmedTransaction {
@@ -835,6 +848,16 @@ impl PrintableTransaction for EncodedConfirmedTransaction {
         println!("EXECUTE {} (slot {})", name, self.slot);
         println_transaction(&tx, &self.transaction.meta, "  ", None, None);
     }
+
+    fn assert_success(&self) {
+        match &self.transaction.meta {
+            Some(meta) if meta.err.is_some() => {
+                self.print();
+                panic!("tx failed!")
+            },
+            _ => (),
+        }
+    }
 }
 
 pub enum LogLevel {
